@@ -1,7 +1,7 @@
 pub mod bitcode;
 mod bits;
 pub mod bitstream;
-mod read;
+pub mod read;
 
 pub use self::bitcode::Bitcode;
 pub use self::bitstream::BitStreamVisitor;
